/****************************/
// AJPS Publication Figures
// This do file uses Stata 14 to produce all of the figures for
// Foreign Aid and the Politics of Undeserved Credit Claiming
// Cesi Cruz and Christina Schneider
//
// For questions, contact Cesi Cruz [cesi.cruz@ubc.ca]
//
// Output and Display Packages: 
// Tables and output generated using Estout, by Ben Jann (available for download at http://repec.org/bocode/e/estout/)
// 
// Analytical Packages:
// RD: Austin Nichols (2011) Revised Stata Module for Regression Discontinuity Estimation. http://ideas.repec.org/c/boc/bocode/s456888.html
// FITSTAT: Goodness-of-fit measures
// All packages can be directly installed from the STATA console using "findit [package name]"
/****************************/

//Modify directory here
cd "/Users/cesicruz/Dropbox/Cesi & Christina/World Bank Paper/AJPS/Final Submission/replication materials/Stata 12 Materials"

use ajps_rdd_data_stata12, clear
drop if prov_geocode==. 

set scheme s1mono

//Regression Discontinuity: full set of observations 
eststo clear
eststo: rd rel_07 kc_cutoff , z0(.76)  cluster(prov_geocode) graph noscatter
esttab using kc_ajps_tables_rd.rtf, ///
	replace title("Regression Discontinuity: KALAHI Participation and Incumbent Reelection in 2007") ///
	eform rtf label nogap unstack compress nonotes nonumbers star(* 0.05) ///
	order(kc_*) mtitles("RD") ///
	se(2) b(a2)  ///
	addnotes("Dependent variable is the reelection of incumbent mayor or relative. Exponentiated coefficients displayed for consistency. * p < 0.05")

	
//Histogram to show Kalahi rankings	
	
//Removes observations without ranking data
drop if kalahi_rank==999
drop if kalahi_rank==.
drop if provincename==""
	
//Dropping pilot sites
drop if (provincename == "QUEZON") & (municityname == "DOLORES")
drop if (provincename == "CAPIZ") & (municityname == "DUMARAO")
drop if (provincename == "BILIRAN") & (municityname == "NAVAL")
drop if (provincename == "DAVAO DEL NORTE") & (municityname == "SANTO TOMAS")
drop if (provincename == "AGUSAN DEL NORTE") & (municityname == "CARMEN")

//Dropping ranking errors
drop if (provincename == "IFUGAO") & (municityname == "HINGYON") //Hingyon was ranked wealthy but it's a 5th class municipality
drop if (provincename == "BOHOL") & (municityname == "GARCIA-HERNANDEZ") //There is a Garcia-Hernandez and a Pres. Garcia municipality that appears to have been switched

//Two possible duplicate observations in Davao
drop if (provincename == "DAVAO DEL NORTE") & (municityname=="SANTO TOMAS") & (first_year==last_year)
drop if (provincename == "DAVAO DEL NORTE") & (municityname=="TALAINGOD") & (first_year==last_year)

//Dropping pilot provinces/unsure rollout/original project documents unavailable
drop if provincename == "MASBATE" | provincename == "ILOILO" | provincename == "LEYTE" | provincename == "LANAO DEL NORTE" | provincename == "ZAMBOANGA DEL NORTE" | ///
	provincename == "NORTH COTABATO" | provincename == "ROMBLON" 
	
twoway (histogram kc_cutoff if kc_project_07==1, width(.05) start(0) fcolor(gray) lcolor(black)) ///
       (histogram kc_cutoff if kc_project_07==0, width(.05)  start(0)   ///
	   fcolor(none) lcolor(black)), xline(.75) xtitle("Poverty Ranking Percentile") legend(order(1 "Kalahi Participant" 2 "Non-participant" )) scheme(s1mono)
	
